#!/bin/bash

#get configs
if [ $# -ne 1 ];
then
	#no config file specified: exit
	echo "no config file specified. Exiting..."
	exit 1
fi
source $1;

#create softlink to startup
cd $ISSM_DIR/test/Verification/NightlyRun/
if [ -e startup.m ]
then
	rm startup.m
fi
ln -s $ISSM_DIR/startup.m .

#Launch all tests on different cpus
for (( i=1;i<=$NUMCPUS_RUN;i++ ))
do
	#Launch matlab and the nightly run script
	cat > $ISSM_DIR/test/Verification/NightlyRun/matlab_run$i.m << EOF
	warning off %necessary to avoid a nightly.log of several Go for cielo_parallel
	try,
	$(if [ "$1" = ""  ]
	then
		echo "nightlyrun;"
	else
		echo "nightlyrun($NROPTIONS,'rank',$i,'numproc',$NUMCPUS_RUN);"
	fi
		)
	catch me,
		%An error occured, get report and exit
		directory=strsplit(pwd,'/');
		message=getReport(me)
		fid=fopen([ISSM_DIR '/test/Verification/NightlyRun/matlaberror.log'], 'at');
		fprintf(fid,'\nMatlab error occured in: %s\n\n',directory{end});
		fprintf(fid,'%s',message);
		fclose(fid);
	end
	exit
EOF
	matlab -nojvm -nosplash  -r matlab_run$i -logfile matlab_log$i.log &
done

wait

#remove matlab_run scripts.
rm -rf matlab_run*.m

#concatenate all reports
mv matlab_log1.log  matlab_log.log
for (( i=2;i<=$NUMCPUS_RUN;i++ ))
do
	cat matlab_log.log matlab_log$i.log > matlab_log.log.bak
	mv matlab_log.log.bak matlab_log.log
	rm matlab_log$i.log

done
